orm — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- core »

# orm

Helper functions related to the connection between the SQLAlchemy ORM and the Camelot Views.

`camelot.core.orm.` `refresh_session`(session)

  Session refresh expires all objects in the current session and sends a local entity update signal via the remote_signals mechanism

  this method ought to be called in the model thread.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- core »

Comments
blog comments powered by Disqus